@@ -37,7 +37,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = @EXPORT_OK;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -65,13 +65,9 @@ sub AUTOLOAD {
 require XSLoader;
 XSLoader::load('Primesieve', $VERSION);
 
-# Preloaded methods go here.
-
-# Autoload methods go after =cut, and are processed by the autosplit program.
 
 1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
 
 =head1 NAME
 
@@ -83,6 +79,10 @@ Primesieve - Perl extension for primesieve
 
   @primes = generate_primes (0,1000);
 
+  my $iterator = Primesieve->new;
+  2 == $iterator->next_prime;
+
+
 =head1 DESCRIPTION
 
 This modules gives you access to primesieve.
@@ -91,6 +91,22 @@ This modules gives you access to primesieve.
 
 =over 4
 
+=item $it = Primesieve->new
+
+Creates an iterator.
+
+=item $it->next_prime
+
+Returns the next prime.
+
+=item $it->prev_prime
+
+Returns the previous prime.
+
+=item $it->skipto ($start, $stop_hint)
+
+Set the position. 
+
 =item @primes = generate_primes ($from, $to)
 
 Returns a list of all primes in the specified range in list context.
@@ -132,7 +148,6 @@ Counts quintuplets primes within the given range.
 
 Counts sextuplets primes within the given range.
 
-
 =item $num = print_primes ($start, $stop)
 
 Print primes within the given range to stdout.
@@ -177,7 +192,6 @@ Sets the sieve size in KiB.
 
 Sets the number of threads.
 
-
 =back
 
 =head1 SEE ALSO
@@ -194,5 +208,3 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.28.1 or,
 at your option, any later version of Perl 5 you may have available.
 
-
-=cut
